@@ -392,11 +392,17 @@ public:
       gameArea->SetFocusedCellMarks(value);
     }
     else {
+      bool hasValue=false;
       for (size_t i=0; i<Sudoku::dimension; i++) {
         if (keypad[i].Valid() && keypad[i]->Get()) {
           gameArea->SetFocusedCellValue(i+1);
+          hasValue=true;
         }
       }
+
+      if (!hasValue) {
+        gameArea->SetFocusedCellValue(Sudoku::empty);
+      }
     }
 
     lock=false;
